package
Version:
v0.0.0-...-6182016
Opens a new window with list of versions in this module.
Published: Dec 14, 2020
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type User struct {
Name string `json:"name" form:"name"`
Age int `json:"age" form:"age"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.